# IocObject

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**custom_fields** | [**CustomFields**](CustomFields.md) |  | [optional] 
**account** | **str** |  | [optional] 
**calculated_time** | **datetime** | Do not set the fields bellow this line | [optional] 
**comment** | **str** |  | [optional] 
**first_seen** | **datetime** |  | [optional] 
**first_seen_entry_id** | **str** |  | [optional] 
**id** | **str** |  | [optional] 
**indicator_type** | **str** |  | [optional] 
**insight_cache** | [**InsightCache**](InsightCache.md) |  | [optional] 
**investigation_i_ds** | **list[str]** |  | [optional] 
**last_reputation_run** | **datetime** |  | [optional] 
**last_seen** | **datetime** |  | [optional] 
**last_seen_entry_id** | **str** |  | [optional] 
**manual_score** | **bool** |  | [optional] 
**manual_set_time** | **datetime** |  | [optional] 
**manually_edited_fields** | **list[str]** |  | [optional] 
**modified** | **datetime** |  | [optional] 
**score** | **int** |  | [optional] 
**set_by** | **str** |  | [optional] 
**sort_values** | **list[str]** |  | [optional] 
**source** | **str** |  | [optional] 
**timestamp** | **datetime** |  | [optional] 
**value** | **str** |  | [optional] 
**version** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


